"""
Interact with GitHub Teams.
"""
# pylint: disable=too-many-lines


class Teams:
    # pylint: disable=too-many-public-methods
    """
    Interact with GitHub Teams.
    """

    def __init__(self, client):
        """
        Initialize the Teams class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_an_external_group(self, org, group_id, payload=None):
        """
        Get an external group
        https://docs.github.com/rest/reference/teams#external-idp-group-info-for-an-organization
        Attributes:
        Path Parameters:
        org
        group_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/external-group/{group_id}"
        response = self._execute("get", url, payload)
        return response

    def list_external_groups_in_an_organization(self, org, payload=None):
        """
        List external groups in an organization
        https://docs.github.com/rest/reference/teams#list-external-idp-groups-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
         display_name
        """
        url = self._base_url + f"/orgs/{org}/external-groups"
        response = self._execute("get", url, payload)
        return response

    def list_idp_groups_for_an_organization(self, org, payload=None):
        """
        List IdP groups for an organization
        https://docs.github.com/rest/reference/teams#list-idp-groups-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/team-sync/groups"
        response = self._execute("get", url, payload)
        return response

    def list_teams(self, org, payload=None):
        """
        List teams
        https://docs.github.com/rest/reference/teams#list-teams
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/teams"
        response = self._execute("get", url, payload)
        return response

    def create_a_team(self, org, payload=None):
        """
        Create a team
        https://docs.github.com/rest/reference/teams#create-a-team
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams"
        response = self._execute("post", url, payload)
        return response

    def get_a_team_by_name(self, org, team_slug, payload=None):
        """
        Get a team by name
        https://docs.github.com/rest/reference/teams#get-a-team-by-name
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}"
        response = self._execute("get", url, payload)
        return response

    def update_a_team(self, org, team_slug, payload=None):
        """
        Update a team
        https://docs.github.com/rest/reference/teams#update-a-team
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_team(self, org, team_slug, payload=None):
        """
        Delete a team
        https://docs.github.com/rest/reference/teams#delete-a-team
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}"
        response = self._execute("delete", url, payload)
        return response

    def list_discussions(self, org, team_slug, payload=None):
        """
        List discussions
        https://docs.github.com/rest/reference/teams#list-discussions
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:
        direction
         per-page
         page
         pinned
        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/discussions"
        response = self._execute("get", url, payload)
        return response

    def create_a_discussion(self, org, team_slug, payload=None):
        """
        Create a discussion
        https://docs.github.com/rest/reference/teams#create-a-discussion
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/discussions"
        response = self._execute("post", url, payload)
        return response

    def get_a_discussion(self, org, team_slug, discussion_number, payload=None):
        """
        Get a discussion
        https://docs.github.com/rest/reference/teams#get-a-discussion
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}"
        response = self._execute("get", url, payload)
        return response

    def update_a_discussion(self, org, team_slug, discussion_number, payload=None):
        """
        Update a discussion
        https://docs.github.com/rest/reference/teams#update-a-discussion
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_discussion(self, org, team_slug, discussion_number, payload=None):
        """
        Delete a discussion
        https://docs.github.com/rest/reference/teams#delete-a-discussion
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}"
        response = self._execute("delete", url, payload)
        return response

    def list_discussion_comments(self, org, team_slug, discussion_number, payload=None):
        """
        List discussion comments
        https://docs.github.com/rest/reference/teams#list-discussion-comments
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        Payload Parameters:
        direction
         per-page
         page
        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments"
        )
        response = self._execute("get", url, payload)
        return response

    def create_a_discussion_comment(self, org, team_slug, discussion_number, payload=None):
        """
        Create a discussion comment
        https://docs.github.com/rest/reference/teams#create-a-discussion-comment
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments"
        )
        response = self._execute("post", url, payload)
        return response

    def get_a_discussion_comment(
        self, org, team_slug, discussion_number, comment_number, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Get a discussion comment
        https://docs.github.com/rest/reference/teams#get-a-discussion-comment
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("get", url, payload)
        return response

    def update_a_discussion_comment(
        self, org, team_slug, discussion_number, comment_number, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Update a discussion comment
        https://docs.github.com/rest/reference/teams#update-a-discussion-comment
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("patch", url, payload)
        return response

    def delete_a_discussion_comment(
        self, org, team_slug, discussion_number, comment_number, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Delete a discussion comment
        https://docs.github.com/rest/reference/teams#delete-a-discussion-comment
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("delete", url, payload)
        return response

    def list_a_connection_between_an_external_group_and_a_team(self, org, team_slug, payload=None):
        """
        List a connection between an external group and a team
        https://docs.github.com/rest/reference/teams#list-external-idp-group-team-connection
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/external-groups"
        response = self._execute("get", url, payload)
        return response

    def update_the_connection_between_an_external_group_and_a_team(
        self, org, team_slug, payload=None
    ):
        """
        Update the connection between an external group and a team
        https://docs.github.com/rest/reference/teams#link-external-idp-group-team-connection
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/external-groups"
        response = self._execute("patch", url, payload)
        return response

    def remove_the_connection_between_an_external_group_and_a_team(
        self, org, team_slug, payload=None
    ):
        """
        Remove the connection between an external group and a team
        https://docs.github.com/rest/reference/teams#unlink-external-idp-group-team-connection
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/external-groups"
        response = self._execute("delete", url, payload)
        return response

    def list_pending_team_invitations(self, org, team_slug, payload=None):
        """
        List pending team invitations
        https://docs.github.com/rest/reference/teams#list-pending-team-invitations
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/invitations"
        response = self._execute("get", url, payload)
        return response

    def list_team_members(self, org, team_slug, payload=None):
        """
        List team members
        https://docs.github.com/rest/reference/teams#list-team-members
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:
        role
         per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/members"
        response = self._execute("get", url, payload)
        return response

    def get_team_membership_for_a_user(self, org, team_slug, username, payload=None):
        """
        Get team membership for a user
        https://docs.github.com/rest/reference/teams#get-team-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        team_slug
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/memberships/{username}"
        response = self._execute("get", url, payload)
        return response

    def add_or_update_team_membership_for_a_user(self, org, team_slug, username, payload=None):
        """
        Add or update team membership for a user
        https://docs.github.com/rest/reference/teams#add-or-update-team-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        team_slug
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/memberships/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_team_membership_for_a_user(self, org, team_slug, username, payload=None):
        """
        Remove team membership for a user
        https://docs.github.com/rest/reference/teams#remove-team-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        team_slug
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/memberships/{username}"
        response = self._execute("delete", url, payload)
        return response

    def list_team_projects(self, org, team_slug, payload=None):
        """
        List team projects
        https://docs.github.com/rest/reference/teams#list-team-projects
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/projects"
        response = self._execute("get", url, payload)
        return response

    def check_team_permissions_for_a_project(self, org, team_slug, project_id, payload=None):
        """
        Check team permissions for a project
        https://docs.github.com/rest/reference/teams#check-team-permissions-for-a-project
        Attributes:
        Path Parameters:
        org
        team_slug
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/projects/{project_id}"
        response = self._execute("get", url, payload)
        return response

    def add_or_update_team_project_permissions(self, org, team_slug, project_id, payload=None):
        """
        Add or update team project permissions
        https://docs.github.com/rest/reference/teams#add-or-update-team-project-permissions
        Attributes:
        Path Parameters:
        org
        team_slug
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/projects/{project_id}"
        response = self._execute("put", url, payload)
        return response

    def remove_a_project_from_a_team(self, org, team_slug, project_id, payload=None):
        """
        Remove a project from a team
        https://docs.github.com/rest/reference/teams#remove-a-project-from-a-team
        Attributes:
        Path Parameters:
        org
        team_slug
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/projects/{project_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_team_repositories(self, org, team_slug, payload=None):
        """
        List team repositories
        https://docs.github.com/rest/reference/teams#list-team-repositories
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/repos"
        response = self._execute("get", url, payload)
        return response

    def check_team_permissions_for_a_repository(
        self, org, team_slug, owner, repo, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Check team permissions for a repository
        https://docs.github.com/rest/reference/teams/#check-team-permissions-for-a-repository
        Attributes:
        Path Parameters:
        org
        team_slug
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/repos/{owner}/{repo}"
        response = self._execute("get", url, payload)
        return response

    def add_or_update_team_repository_permissions(
        self, org, team_slug, owner, repo, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Add or update team repository permissions
        https://docs.github.com/rest/reference/teams/#add-or-update-team-repository-permissions
        Attributes:
        Path Parameters:
        org
        team_slug
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/repos/{owner}/{repo}"
        response = self._execute("put", url, payload)
        return response

    def remove_a_repository_from_a_team(
        self, org, team_slug, owner, repo, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Remove a repository from a team
        https://docs.github.com/rest/reference/teams/#remove-a-repository-from-a-team
        Attributes:
        Path Parameters:
        org
        team_slug
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/repos/{owner}/{repo}"
        response = self._execute("delete", url, payload)
        return response

    def list_idp_groups_for_a_team(self, org, team_slug, payload=None):
        """
        List IdP groups for a team
        https://docs.github.com/rest/reference/teams#list-idp-groups-for-a-team
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/team-sync/group-mappings"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_idp_group_connections(self, org, team_slug, payload=None):
        """
        Create or update IdP group connections
        https://docs.github.com/rest/reference/teams#create-or-update-idp-group-connections
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/team-sync/group-mappings"
        response = self._execute("patch", url, payload)
        return response

    def list_child_teams(self, org, team_slug, payload=None):
        """
        List child teams
        https://docs.github.com/rest/reference/teams#list-child-teams
        Attributes:
        Path Parameters:
        org
        team_slug
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/teams/{team_slug}/teams"
        response = self._execute("get", url, payload)
        return response

    def get_a_team__legacy(self, team_id, payload=None):
        """
        Get a team (Legacy)
        https://docs.github.com/rest/reference/teams/#get-a-team-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_team__legacy(self, team_id, payload=None):
        """
        Update a team (Legacy)
        https://docs.github.com/rest/reference/teams/#update-a-team-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_team__legacy(self, team_id, payload=None):
        """
        Delete a team (Legacy)
        https://docs.github.com/rest/reference/teams/#delete-a-team-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_discussions__legacy(self, team_id, payload=None):
        """
        List discussions (Legacy)
        https://docs.github.com/rest/reference/teams#list-discussions-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:
        direction
         per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/discussions"
        response = self._execute("get", url, payload)
        return response

    def create_a_discussion__legacy(self, team_id, payload=None):
        """
        Create a discussion (Legacy)
        https://docs.github.com/rest/reference/teams#create-a-discussion-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/discussions"
        response = self._execute("post", url, payload)
        return response

    def get_a_discussion__legacy(self, team_id, discussion_number, payload=None):
        """
        Get a discussion (Legacy)
        https://docs.github.com/rest/reference/teams#get-a-discussion-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}"
        response = self._execute("get", url, payload)
        return response

    def update_a_discussion__legacy(self, team_id, discussion_number, payload=None):
        """
        Update a discussion (Legacy)
        https://docs.github.com/rest/reference/teams#update-a-discussion-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_discussion__legacy(self, team_id, discussion_number, payload=None):
        """
        Delete a discussion (Legacy)
        https://docs.github.com/rest/reference/teams#delete-a-discussion-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}"
        response = self._execute("delete", url, payload)
        return response

    def list_discussion_comments__legacy(self, team_id, discussion_number, payload=None):
        """
        List discussion comments (Legacy)
        https://docs.github.com/rest/reference/teams#list-discussion-comments-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        Payload Parameters:
        direction
         per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/comments"
        response = self._execute("get", url, payload)
        return response

    def create_a_discussion_comment__legacy(self, team_id, discussion_number, payload=None):
        """
        Create a discussion comment (Legacy)
        https://docs.github.com/rest/reference/teams#create-a-discussion-comment-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/comments"
        response = self._execute("post", url, payload)
        return response

    def get_a_discussion_comment__legacy(
        self, team_id, discussion_number, comment_number, payload=None
    ):
        """
        Get a discussion comment (Legacy)
        https://docs.github.com/rest/reference/teams#get-a-discussion-comment-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}"
        )
        response = self._execute("get", url, payload)
        return response

    def update_a_discussion_comment__legacy(
        self, team_id, discussion_number, comment_number, payload=None
    ):
        """
        Update a discussion comment (Legacy)
        https://docs.github.com/rest/reference/teams#update-a-discussion-comment-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}"
        )
        response = self._execute("patch", url, payload)
        return response

    def delete_a_discussion_comment__legacy(
        self, team_id, discussion_number, comment_number, payload=None
    ):
        """
        Delete a discussion comment (Legacy)
        https://docs.github.com/rest/reference/teams#delete-a-discussion-comment-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_pending_team_invitations__legacy(self, team_id, payload=None):
        """
        List pending team invitations (Legacy)
        https://docs.github.com/rest/reference/teams#list-pending-team-invitations-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/invitations"
        response = self._execute("get", url, payload)
        return response

    def list_team_members__legacy(self, team_id, payload=None):
        """
        List team members (Legacy)
        https://docs.github.com/rest/reference/teams#list-team-members-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:
        role
         per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/members"
        response = self._execute("get", url, payload)
        return response

    def get_team_member__legacy(self, team_id, username, payload=None):
        """
        Get team member (Legacy)
        https://docs.github.com/rest/reference/teams#get-team-member-legacy
        Attributes:
        Path Parameters:
        team_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/members/{username}"
        response = self._execute("get", url, payload)
        return response

    def add_team_member__legacy(self, team_id, username, payload=None):
        """
        Add team member (Legacy)
        https://docs.github.com/rest/reference/teams#add-team-member-legacy
        Attributes:
        Path Parameters:
        team_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/members/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_team_member__legacy(self, team_id, username, payload=None):
        """
        Remove team member (Legacy)
        https://docs.github.com/rest/reference/teams#remove-team-member-legacy
        Attributes:
        Path Parameters:
        team_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/members/{username}"
        response = self._execute("delete", url, payload)
        return response

    def get_team_membership_for_a_user__legacy(self, team_id, username, payload=None):
        """
        Get team membership for a user (Legacy)
        https://docs.github.com/rest/reference/teams#get-team-membership-for-a-user-legacy
        Attributes:
        Path Parameters:
        team_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/memberships/{username}"
        response = self._execute("get", url, payload)
        return response

    def add_or_update_team_membership_for_a_user__legacy(self, team_id, username, payload=None):
        """
        Add or update team membership for a user (Legacy)
        https://docs.github.com/rest/reference/teams#add-or-update-team-membership-for-a-user-legacy
        Attributes:
        Path Parameters:
        team_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/memberships/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_team_membership_for_a_user__legacy(self, team_id, username, payload=None):
        """
        Remove team membership for a user (Legacy)
        https://docs.github.com/rest/reference/teams#remove-team-membership-for-a-user-legacy
        Attributes:
        Path Parameters:
        team_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/memberships/{username}"
        response = self._execute("delete", url, payload)
        return response

    def list_team_projects__legacy(self, team_id, payload=None):
        """
        List team projects (Legacy)
        https://docs.github.com/rest/reference/teams/#list-team-projects-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/projects"
        response = self._execute("get", url, payload)
        return response

    def check_team_permissions_for_a_project__legacy(self, team_id, project_id, payload=None):
        """
        Check team permissions for a project (Legacy)
        https://docs.github.com/rest/reference/teams/#check-team-permissions-for-a-project-legacy
        Attributes:
        Path Parameters:
        team_id
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/projects/{project_id}"
        response = self._execute("get", url, payload)
        return response

    def add_or_update_team_project_permissions__legacy(self, team_id, project_id, payload=None):
        """
        Add or update team project permissions (Legacy)
        https://docs.github.com/rest/reference/teams/#add-or-update-team-project-permissions-legacy
        Attributes:
        Path Parameters:
        team_id
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/projects/{project_id}"
        response = self._execute("put", url, payload)
        return response

    def remove_a_project_from_a_team__legacy(self, team_id, project_id, payload=None):
        """
        Remove a project from a team (Legacy)
        https://docs.github.com/rest/reference/teams/#remove-a-project-from-a-team-legacy
        Attributes:
        Path Parameters:
        team_id
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/projects/{project_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_team_repositories__legacy(self, team_id, payload=None):
        """
        List team repositories (Legacy)
        https://docs.github.com/rest/reference/teams/#list-team-repositories-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/repos"
        response = self._execute("get", url, payload)
        return response

    def check_team_permissions_for_a_repository__legacy(self, team_id, owner, repo, payload=None):
        """
        Check team permissions for a repository (Legacy)
        https://docs.github.com/rest/reference/teams/#check-team-permissions-for-a-repository-legacy
        Attributes:
        Path Parameters:
        team_id
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/repos/{owner}/{repo}"
        response = self._execute("get", url, payload)
        return response

    def add_or_update_team_repository_permissions__legacy(self, team_id, owner, repo, payload=None):
        """
        Add or update team repository permissions (Legacy)
        https://docs.github.com/rest/reference/teams/#add-or-update-team-repository-permissions-legacy
        Attributes:
        Path Parameters:
        team_id
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/repos/{owner}/{repo}"
        response = self._execute("put", url, payload)
        return response

    def remove_a_repository_from_a_team__legacy(self, team_id, owner, repo, payload=None):
        """
        Remove a repository from a team (Legacy)
        https://docs.github.com/rest/reference/teams/#remove-a-repository-from-a-team-legacy
        Attributes:
        Path Parameters:
        team_id
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/repos/{owner}/{repo}"
        response = self._execute("delete", url, payload)
        return response

    def list_idp_groups_for_a_team__legacy(self, team_id, payload=None):
        """
        List IdP groups for a team (Legacy)
        https://docs.github.com/rest/reference/teams#list-idp-groups-for-a-team-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/team-sync/group-mappings"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_idp_group_connections__legacy(self, team_id, payload=None):
        """
        Create or update IdP group connections (Legacy)
        https://docs.github.com/rest/reference/teams#create-or-update-idp-group-connections-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/team-sync/group-mappings"
        response = self._execute("patch", url, payload)
        return response

    def list_child_teams__legacy(self, team_id, payload=None):
        """
        List child teams (Legacy)
        https://docs.github.com/rest/reference/teams/#list-child-teams-legacy
        Attributes:
        Path Parameters:
        team_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/teams"
        response = self._execute("get", url, payload)
        return response

    def list_teams_for_the_authenticated_user(self, payload=None):
        """
        List teams for the authenticated user
        https://docs.github.com/rest/reference/teams#list-teams-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/teams"
        response = self._execute("get", url, payload)
        return response



"""
Raw Git functionality.
"""


class Git:
    """
    Raw Git functionality.
    """

    def __init__(self, client):
        """
        Initialize the Git class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def create_a_blob(self, owner, repo, payload=None):
        """
        Create a blob
        https://docs.github.com/rest/reference/git#create-a-blob
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/blobs"
        response = self._execute("post", url, payload)
        return response

    def get_a_blob(self, owner, repo, file_sha, payload=None):
        """
        Get a blob
        https://docs.github.com/rest/reference/git#get-a-blob
        Attributes:
        Path Parameters:
        owner
        repo
        file_sha
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/blobs/{file_sha}"
        response = self._execute("get", url, payload)
        return response

    def create_a_commit(self, owner, repo, payload=None):
        """
        Create a commit
        https://docs.github.com/rest/reference/git#create-a-commit
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/commits"
        response = self._execute("post", url, payload)
        return response

    def get_a_commit(self, owner, repo, commit_sha, payload=None):
        """
        Get a commit
        https://docs.github.com/rest/reference/git#get-a-commit
        Attributes:
        Path Parameters:
        owner
        repo
        commit_sha
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/commits/{commit_sha}"
        response = self._execute("get", url, payload)
        return response

    def list_matching_references(self, owner, repo, ref, payload=None):
        """
        List matching references
        https://docs.github.com/rest/reference/git#list-matching-references
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/matching-refs/{ref}"
        response = self._execute("get", url, payload)
        return response

    def get_a_reference(self, owner, repo, ref, payload=None):
        """
        Get a reference
        https://docs.github.com/rest/reference/git#get-a-reference
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/ref/{ref}"
        response = self._execute("get", url, payload)
        return response

    def create_a_reference(self, owner, repo, payload=None):
        """
        Create a reference
        https://docs.github.com/rest/reference/git#create-a-reference
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/refs"
        response = self._execute("post", url, payload)
        return response

    def get_all_references_in_a_namespace(self, owner, repo, namespace, payload=None):
        """
        Get all references in a namespace
        https://docs.github.com/rest/reference/git#get-a-reference
        Attributes:
        Path Parameters:
        owner
        repo
        namespace
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/refs/{namespace}"
        response = self._execute("get", url, payload)
        return response

    def update_a_reference(self, owner, repo, ref, payload=None):
        """
        Update a reference
        https://docs.github.com/rest/reference/git#update-a-reference
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/refs/{ref}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_reference(self, owner, repo, ref, payload=None):
        """
        Delete a reference
        https://docs.github.com/rest/reference/git#delete-a-reference
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/refs/{ref}"
        response = self._execute("delete", url, payload)
        return response

    def create_a_tag_object(self, owner, repo, payload=None):
        """
        Create a tag object
        https://docs.github.com/rest/reference/git#create-a-tag-object
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/tags"
        response = self._execute("post", url, payload)
        return response

    def get_a_tag(self, owner, repo, tag_sha, payload=None):
        """
        Get a tag
        https://docs.github.com/rest/reference/git#get-a-tag
        Attributes:
        Path Parameters:
        owner
        repo
        tag_sha
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/tags/{tag_sha}"
        response = self._execute("get", url, payload)
        return response

    def create_a_tree(self, owner, repo, payload=None):
        """
        Create a tree
        https://docs.github.com/rest/reference/git#create-a-tree
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/trees"
        response = self._execute("post", url, payload)
        return response

    def get_a_tree(self, owner, repo, tree_sha, payload=None):
        """
        Get a tree
        https://docs.github.com/rest/reference/git#get-a-tree
        Attributes:
        Path Parameters:
        owner
        repo
        tree_sha
        Payload Parameters:
        recursive
        """
        url = self._base_url + f"/repos/{owner}/{repo}/git/trees/{tree_sha}"
        response = self._execute("get", url, payload)
        return response



"""
Check your current rate limit status
"""


class RateLimit:
    # pylint: disable=too-few-public-methods
    """
    Check your current rate limit status
    """

    def __init__(self, client):
        """
        Initialize the RateLimit class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_rate_limit_status_for_the_authenticated_user(self, payload=None):
        """
        Get rate limit status for the authenticated user
        https://docs.github.com/rest/reference/rate-limit#get-rate-limit-status-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/rate_limit"
        response = self._execute("get", url, payload)
        return response



"""
Render GitHub flavored markdown
"""


class Markdown:
    """
    Render GitHub flavored markdown
    """

    def __init__(self, client):
        """
        Initialize the Markdown class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def render_a_markdown_document(self, payload=None):
        """
        Render a Markdown document
        https://docs.github.com/rest/reference/markdown#render-a-markdown-document
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/markdown"
        response = self._execute("post", url, payload)
        return response

    def render_a_markdown_document_in_raw_mode(self, payload=None):
        """
        Render a Markdown document in raw mode
        https://docs.github.com/rest/reference/markdown#render-a-markdown-document-in-raw-mode
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/markdown/raw"
        response = self._execute("post", url, payload)
        return response



"""
Information for integrations and installations.
"""


class Apps:
    # pylint: disable=too-many-public-methods
    """
    Information for integrations and installations.
    """

    def __init__(self, client):
        """
        Initialize the Apps class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_the_authenticated_app(self, payload=None):
        """
        Get the authenticated app
        https://docs.github.com/rest/reference/apps#get-the-authenticated-app
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/app"
        response = self._execute("get", url, payload)
        return response

    def create_a_github_app_from_a_manifest(self, code, payload=None):
        """
        Create a GitHub App from a manifest
        https://docs.github.com/rest/reference/apps#create-a-github-app-from-a-manifest
        Attributes:
        Path Parameters:
        code
        Payload Parameters:

        """
        url = self._base_url + f"/app-manifests/{code}/conversions"
        response = self._execute("post", url, payload)
        return response

    def get_a_webhook_configuration_for_an_app(self, payload=None):
        """
        Get a webhook configuration for an app
        https://docs.github.com/rest/reference/apps#get-a-webhook-configuration-for-an-app
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/app/hook/config"
        response = self._execute("get", url, payload)
        return response

    def update_a_webhook_configuration_for_an_app(self, payload=None):
        """
        Update a webhook configuration for an app
        https://docs.github.com/rest/reference/apps#update-a-webhook-configuration-for-an-app
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/app/hook/config"
        response = self._execute("patch", url, payload)
        return response

    def list_deliveries_for_an_app_webhook(self, payload=None):
        """
        List deliveries for an app webhook
        https://docs.github.com/rest/reference/apps#list-deliveries-for-an-app-webhook
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         cursor
        """
        url = self._base_url + "/app/hook/deliveries"
        response = self._execute("get", url, payload)
        return response

    def get_a_delivery_for_an_app_webhook(self, delivery_id, payload=None):
        """
        Get a delivery for an app webhook
        https://docs.github.com/rest/reference/apps#get-a-delivery-for-an-app-webhook
        Attributes:
        Path Parameters:
        delivery_id
        Payload Parameters:

        """
        url = self._base_url + f"/app/hook/deliveries/{delivery_id}"
        response = self._execute("get", url, payload)
        return response

    def redeliver_a_delivery_for_an_app_webhook(self, delivery_id, payload=None):
        """
        Redeliver a delivery for an app webhook
        https://docs.github.com/rest/reference/apps#redeliver-a-delivery-for-an-app-webhook
        Attributes:
        Path Parameters:
        delivery_id
        Payload Parameters:

        """
        url = self._base_url + f"/app/hook/deliveries/{delivery_id}/attempts"
        response = self._execute("post", url, payload)
        return response

    def list_installations_for_the_authenticated_app(self, payload=None):
        """
        List installations for the authenticated app
        https://docs.github.com/rest/reference/apps#list-installations-for-the-authenticated-app
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
         since
         outdated
        """
        url = self._base_url + "/app/installations"
        response = self._execute("get", url, payload)
        return response

    def get_an_installation_for_the_authenticated_app(self, installation_id, payload=None):
        """
        Get an installation for the authenticated app
        https://docs.github.com/rest/reference/apps#get-an-installation-for-the-authenticated-app
        Attributes:
        Path Parameters:
        installation_id
        Payload Parameters:

        """
        url = self._base_url + f"/app/installations/{installation_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_an_installation_for_the_authenticated_app(self, installation_id, payload=None):
        """
        Delete an installation for the authenticated app
        https://docs.github.com/rest/reference/apps#delete-an-installation-for-the-authenticated-app
        Attributes:
        Path Parameters:
        installation_id
        Payload Parameters:

        """
        url = self._base_url + f"/app/installations/{installation_id}"
        response = self._execute("delete", url, payload)
        return response

    def create_an_installation_access_token_for_an_app(self, installation_id, payload=None):
        """
        Create an installation access token for an app
        https://docs.github.com/rest/reference/apps/#create-an-installation-access-token-for-an-app
        Attributes:
        Path Parameters:
        installation_id
        Payload Parameters:

        """
        url = self._base_url + f"/app/installations/{installation_id}/access_tokens"
        response = self._execute("post", url, payload)
        return response

    def suspend_an_app_installation(self, installation_id, payload=None):
        """
        Suspend an app installation
        https://docs.github.com/rest/reference/apps#suspend-an-app-installation
        Attributes:
        Path Parameters:
        installation_id
        Payload Parameters:

        """
        url = self._base_url + f"/app/installations/{installation_id}/suspended"
        response = self._execute("put", url, payload)
        return response

    def unsuspend_an_app_installation(self, installation_id, payload=None):
        """
        Unsuspend an app installation
        https://docs.github.com/rest/reference/apps#unsuspend-an-app-installation
        Attributes:
        Path Parameters:
        installation_id
        Payload Parameters:

        """
        url = self._base_url + f"/app/installations/{installation_id}/suspended"
        response = self._execute("delete", url, payload)
        return response

    def delete_an_app_authorization(self, client_id, payload=None):
        """
        Delete an app authorization
        https://docs.github.com/rest/reference/apps#delete-an-app-authorization
        Attributes:
        Path Parameters:
        client_id
        Payload Parameters:

        """
        url = self._base_url + f"/applications/{client_id}/grant"
        response = self._execute("delete", url, payload)
        return response

    def check_a_token(self, client_id, payload=None):
        """
        Check a token
        https://docs.github.com/rest/reference/apps#check-a-token
        Attributes:
        Path Parameters:
        client_id
        Payload Parameters:

        """
        url = self._base_url + f"/applications/{client_id}/token"
        response = self._execute("post", url, payload)
        return response

    def reset_a_token(self, client_id, payload=None):
        """
        Reset a token
        https://docs.github.com/rest/reference/apps#reset-a-token
        Attributes:
        Path Parameters:
        client_id
        Payload Parameters:

        """
        url = self._base_url + f"/applications/{client_id}/token"
        response = self._execute("patch", url, payload)
        return response

    def delete_an_app_token(self, client_id, payload=None):
        """
        Delete an app token
        https://docs.github.com/rest/reference/apps#delete-an-app-token
        Attributes:
        Path Parameters:
        client_id
        Payload Parameters:

        """
        url = self._base_url + f"/applications/{client_id}/token"
        response = self._execute("delete", url, payload)
        return response

    def create_a_scoped_access_token(self, client_id, payload=None):
        """
        Create a scoped access token
        https://docs.github.com/rest/reference/apps#create-a-scoped-access-token
        Attributes:
        Path Parameters:
        client_id
        Payload Parameters:

        """
        url = self._base_url + f"/applications/{client_id}/token/scoped"
        response = self._execute("post", url, payload)
        return response

    def get_an_app(self, app_slug, payload=None):
        """
        Get an app
        https://docs.github.com/rest/reference/apps/#get-an-app
        Attributes:
        Path Parameters:
        app_slug
        Payload Parameters:

        """
        url = self._base_url + f"/apps/{app_slug}"
        response = self._execute("get", url, payload)
        return response

    def list_repositories_accessible_to_the_app_installation(self, payload=None):
        """
        List repositories accessible to the app installation
        https://docs.github.com/rest/reference/apps#list-repositories-accessible-to-the-app-installation
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/installation/repositories"
        response = self._execute("get", url, payload)
        return response

    def revoke_an_installation_access_token(self, payload=None):
        """
        Revoke an installation access token
        https://docs.github.com/rest/reference/apps#revoke-an-installation-access-token
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/installation/token"
        response = self._execute("delete", url, payload)
        return response

    def get_a_subscription_plan_for_an_account(self, account_id, payload=None):
        """
        Get a subscription plan for an account
        https://docs.github.com/rest/reference/apps#get-a-subscription-plan-for-an-account
        Attributes:
        Path Parameters:
        account_id
        Payload Parameters:

        """
        url = self._base_url + f"/marketplace_listing/accounts/{account_id}"
        response = self._execute("get", url, payload)
        return response

    def list_plans(self, payload=None):
        """
        List plans
        https://docs.github.com/rest/reference/apps#list-plans
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/marketplace_listing/plans"
        response = self._execute("get", url, payload)
        return response

    def list_accounts_for_a_plan(self, plan_id, payload=None):
        """
        List accounts for a plan
        https://docs.github.com/rest/reference/apps#list-accounts-for-a-plan
        Attributes:
        Path Parameters:
        plan_id
        Payload Parameters:
        sort
         direction
         per-page
         page
        """
        url = self._base_url + f"/marketplace_listing/plans/{plan_id}/accounts"
        response = self._execute("get", url, payload)
        return response

    def get_a_subscription_plan_for_an_account__stubbed(self, account_id, payload=None):
        """
        Get a subscription plan for an account (stubbed)
        https://docs.github.com/rest/reference/apps#get-a-subscription-plan-for-an-account-stubbed
        Attributes:
        Path Parameters:
        account_id
        Payload Parameters:

        """
        url = self._base_url + f"/marketplace_listing/stubbed/accounts/{account_id}"
        response = self._execute("get", url, payload)
        return response

    def list_plans__stubbed(self, payload=None):
        """
        List plans (stubbed)
        https://docs.github.com/rest/reference/apps#list-plans-stubbed
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/marketplace_listing/stubbed/plans"
        response = self._execute("get", url, payload)
        return response

    def list_accounts_for_a_plan__stubbed(self, plan_id, payload=None):
        """
        List accounts for a plan (stubbed)
        https://docs.github.com/rest/reference/apps#list-accounts-for-a-plan-stubbed
        Attributes:
        Path Parameters:
        plan_id
        Payload Parameters:
        sort
         direction
         per-page
         page
        """
        url = self._base_url + f"/marketplace_listing/stubbed/plans/{plan_id}/accounts"
        response = self._execute("get", url, payload)
        return response

    def get_an_organization_installation_for_the_authenticated_app(self, org, payload=None):
        """
        Get an organization installation for the authenticated app
        https://docs.github.com/rest/reference/apps#get-an-organization-installation-for-the-authenticated-app
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/installation"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_installation_for_the_authenticated_app(self, owner, repo, payload=None):
        """
        Get a repository installation for the authenticated app
        https://docs.github.com/rest/reference/apps#get-a-repository-installation-for-the-authenticated-app
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/installation"
        response = self._execute("get", url, payload)
        return response

    def list_app_installations_accessible_to_the_user_access_token(self, payload=None):
        """
        List app installations accessible to the user access token
        https://docs.github.com/rest/reference/apps#list-app-installations-accessible-to-the-user-access-token
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/installations"
        response = self._execute("get", url, payload)
        return response

    def list_repositories_accessible_to_the_user_access_token(self, installation_id, payload=None):
        """
        List repositories accessible to the user access token
        https://docs.github.com/rest/reference/apps#list-repositories-accessible-to-the-user-access-token
        Attributes:
        Path Parameters:
        installation_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/user/installations/{installation_id}/repositories"
        response = self._execute("get", url, payload)
        return response

    def add_a_repository_to_an_app_installation(self, installation_id, repository_id, payload=None):
        """
        Add a repository to an app installation
        https://docs.github.com/rest/reference/apps#add-a-repository-to-an-app-installation
        Attributes:
        Path Parameters:
        installation_id
        repository_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/installations/{installation_id}/repositories/{repository_id}"
        response = self._execute("put", url, payload)
        return response

    def remove_a_repository_from_an_app_installation(
        self, installation_id, repository_id, payload=None
    ):
        """
        Remove a repository from an app installation
        https://docs.github.com/rest/reference/apps#remove-a-repository-from-an-app-installation
        Attributes:
        Path Parameters:
        installation_id
        repository_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/installations/{installation_id}/repositories/{repository_id}"
        response = self._execute("delete", url, payload)
        return response

    def search_user_repositories_related_to_integration_installation(
        self, installation_id, payload=None
    ):
        """
        Search user repositories related to integration installation
        https://docs.github.com/rest/reference/apps#search-user-repositories-related-to-integration
        Attributes:
        Path Parameters:
        installation_id
        Payload Parameters:
        q
         sort
         order
         per-page
         page
        """
        url = self._base_url + f"/user/installations/{installation_id}/search/repositories"
        response = self._execute("get", url, payload)
        return response

    def list_subscriptions_for_the_authenticated_user(self, payload=None):
        """
        List subscriptions for the authenticated user
        https://docs.github.com/rest/reference/apps#list-subscriptions-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/marketplace_purchases"
        response = self._execute("get", url, payload)
        return response

    def list_subscriptions_for_the_authenticated_user__stubbed(self, payload=None):
        """
        List subscriptions for the authenticated user (stubbed)
        https://docs.github.com/rest/reference/apps#list-subscriptions-for-the-authenticated-user-stubbed
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/marketplace_purchases/stubbed"
        response = self._execute("get", url, payload)
        return response

    def get_a_user_installation_for_the_authenticated_app(self, username, payload=None):
        """
        Get a user installation for the authenticated app
        https://docs.github.com/rest/reference/apps#get-a-user-installation-for-the-authenticated-app
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/users/{username}/installation"
        response = self._execute("get", url, payload)
        return response



"""
Init file for the graph package.
"""
from .graph_client import GraphClient, GraphClientError  # noqa: F401
from .graph_mutation import GraphMutation  # noqa: F401
from .graph_query import GraphQuery  # noqa: F401



"""
Interact with GitHub Repos.
"""
# pylint: disable=too-many-lines


class Repos:
    # pylint: disable=too-many-public-methods
    """
    Interact with GitHub Repos.
    """

    def __init__(self, client):
        """
        Initialize the Repos class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_organization_repositories(self, org, payload=None):
        """
        List organization repositories
        https://docs.github.com/rest/reference/repos#list-organization-repositories
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        type
         sort
         direction
         per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/repos"
        response = self._execute("get", url, payload)
        return response

    def create_an_organization_repository(self, org, payload=None):
        """
        Create an organization repository
        https://docs.github.com/rest/reference/repos#create-an-organization-repository
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/repos"
        response = self._execute("post", url, payload)
        return response

    def get_a_repository(self, owner, repo, payload=None):
        """
        Get a repository
        https://docs.github.com/rest/reference/repos#get-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}"
        response = self._execute("get", url, payload)
        return response

    def update_a_repository(self, owner, repo, payload=None):
        """
        Update a repository
        https://docs.github.com/rest/reference/repos/#update-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_repository(self, owner, repo, payload=None):
        """
        Delete a repository
        https://docs.github.com/rest/reference/repos#delete-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}"
        response = self._execute("delete", url, payload)
        return response

    def list_all_autolinks_of_a_repository(self, owner, repo, payload=None):
        """
        List all autolinks of a repository
        https://docs.github.com/v3/repos#list-autolinks
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/autolinks"
        response = self._execute("get", url, payload)
        return response

    def create_an_autolink_reference_for_a_repository(self, owner, repo, payload=None):
        """
        Create an autolink reference for a repository
        https://docs.github.com/v3/repos#create-an-autolink
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/autolinks"
        response = self._execute("post", url, payload)
        return response

    def get_an_autolink_reference_of_a_repository(self, owner, repo, autolink_id, payload=None):
        """
        Get an autolink reference of a repository
        https://docs.github.com/v3/repos#get-autolink
        Attributes:
        Path Parameters:
        owner
        repo
        autolink_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/autolinks/{autolink_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_an_autolink_reference_from_a_repository(
        self, owner, repo, autolink_id, payload=None
    ):
        """
        Delete an autolink reference from a repository
        https://docs.github.com/v3/repos#delete-autolink
        Attributes:
        Path Parameters:
        owner
        repo
        autolink_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/autolinks/{autolink_id}"
        response = self._execute("delete", url, payload)
        return response

    def enable_automated_security_fixes(self, owner, repo, payload=None):
        """
        Enable automated security fixes
        https://docs.github.com/rest/reference/repos#enable-automated-security-fixes
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/automated-security-fixes"
        response = self._execute("put", url, payload)
        return response

    def disable_automated_security_fixes(self, owner, repo, payload=None):
        """
        Disable automated security fixes
        https://docs.github.com/rest/reference/repos#disable-automated-security-fixes
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/automated-security-fixes"
        response = self._execute("delete", url, payload)
        return response

    def list_branches(self, owner, repo, payload=None):
        """
        List branches
        https://docs.github.com/rest/reference/repos#list-branches
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        protected
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches"
        response = self._execute("get", url, payload)
        return response

    def get_a_branch(self, owner, repo, branch, payload=None):
        """
        Get a branch
        https://docs.github.com/rest/reference/repos#get-a-branch
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}"
        response = self._execute("get", url, payload)
        return response

    def get_branch_protection(self, owner, repo, branch, payload=None):
        """
        Get branch protection
        https://docs.github.com/rest/reference/repos#get-branch-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection"
        response = self._execute("get", url, payload)
        return response

    def update_branch_protection(self, owner, repo, branch, payload=None):
        """
        Update branch protection
        https://docs.github.com/rest/reference/repos#update-branch-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection"
        response = self._execute("put", url, payload)
        return response

    def delete_branch_protection(self, owner, repo, branch, payload=None):
        """
        Delete branch protection
        https://docs.github.com/rest/reference/repos#delete-branch-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection"
        response = self._execute("delete", url, payload)
        return response

    def get_admin_branch_protection(self, owner, repo, branch, payload=None):
        """
        Get admin branch protection
        https://docs.github.com/rest/reference/repos#get-admin-branch-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/enforce_admins"
        response = self._execute("get", url, payload)
        return response

    def set_admin_branch_protection(self, owner, repo, branch, payload=None):
        """
        Set admin branch protection
        https://docs.github.com/rest/reference/repos#set-admin-branch-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/enforce_admins"
        response = self._execute("post", url, payload)
        return response

    def delete_admin_branch_protection(self, owner, repo, branch, payload=None):
        """
        Delete admin branch protection
        https://docs.github.com/rest/reference/repos#delete-admin-branch-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/enforce_admins"
        response = self._execute("delete", url, payload)
        return response

    def get_pull_request_review_protection(self, owner, repo, branch, payload=None):
        """
        Get pull request review protection
        https://docs.github.com/rest/reference/repos#get-pull-request-review-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_pull_request_reviews"
        )
        response = self._execute("get", url, payload)
        return response

    def update_pull_request_review_protection(self, owner, repo, branch, payload=None):
        """
        Update pull request review protection
        https://docs.github.com/rest/reference/repos#update-pull-request-review-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_pull_request_reviews"
        )
        response = self._execute("patch", url, payload)
        return response

    def delete_pull_request_review_protection(self, owner, repo, branch, payload=None):
        """
        Delete pull request review protection
        https://docs.github.com/rest/reference/repos#delete-pull-request-review-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_pull_request_reviews"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_commit_signature_protection(self, owner, repo, branch, payload=None):
        """
        Get commit signature protection
        https://docs.github.com/rest/reference/repos#get-commit-signature-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_signatures"
        )
        response = self._execute("get", url, payload)
        return response

    def create_commit_signature_protection(self, owner, repo, branch, payload=None):
        """
        Create commit signature protection
        https://docs.github.com/rest/reference/repos#create-commit-signature-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_signatures"
        )
        response = self._execute("post", url, payload)
        return response

    def delete_commit_signature_protection(self, owner, repo, branch, payload=None):
        """
        Delete commit signature protection
        https://docs.github.com/rest/reference/repos#delete-commit-signature-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_signatures"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_status_checks_protection(self, owner, repo, branch, payload=None):
        """
        Get status checks protection
        https://docs.github.com/rest/reference/repos#get-status-checks-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_status_checks"
        )
        response = self._execute("get", url, payload)
        return response

    def update_status_check_protection(self, owner, repo, branch, payload=None):
        """
        Update status check protection
        https://docs.github.com/rest/reference/repos#update-status-check-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_status_checks"
        )
        response = self._execute("patch", url, payload)
        return response

    def remove_status_check_protection(self, owner, repo, branch, payload=None):
        """
        Remove status check protection
        https://docs.github.com/rest/reference/repos#remove-status-check-protection
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_status_checks"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_all_status_check_contexts(self, owner, repo, branch, payload=None):
        """
        Get all status check contexts
        https://docs.github.com/rest/reference/repos#get-all-status-check-contexts
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_status_checks/contexts"
        )
        response = self._execute("get", url, payload)
        return response

    def add_status_check_contexts(self, owner, repo, branch, payload=None):
        """
        Add status check contexts
        https://docs.github.com/rest/reference/repos#add-status-check-contexts
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_status_checks/contexts"
        )
        response = self._execute("post", url, payload)
        return response

    def set_status_check_contexts(self, owner, repo, branch, payload=None):
        """
        Set status check contexts
        https://docs.github.com/rest/reference/repos#set-status-check-contexts
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_status_checks/contexts"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_status_check_contexts(self, owner, repo, branch, payload=None):
        """
        Remove status check contexts
        https://docs.github.com/rest/reference/repos#remove-status-check-contexts
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/required_status_checks/contexts"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Get access restrictions
        https://docs.github.com/rest/reference/repos#get-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions"
        response = self._execute("get", url, payload)
        return response

    def delete_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Delete access restrictions
        https://docs.github.com/rest/reference/repos#delete-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions"
        response = self._execute("delete", url, payload)
        return response

    def get_apps_with_access_to_the_protected_branch(self, owner, repo, branch, payload=None):
        """
        Get apps with access to the protected branch
        https://docs.github.com/rest/reference/repos#list-apps-with-access-to-the-protected-branch
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/apps"
        )
        response = self._execute("get", url, payload)
        return response

    def add_app_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Add app access restrictions
        https://docs.github.com/rest/reference/repos#add-app-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/apps"
        )
        response = self._execute("post", url, payload)
        return response

    def set_app_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Set app access restrictions
        https://docs.github.com/rest/reference/repos#set-app-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/apps"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_app_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Remove app access restrictions
        https://docs.github.com/rest/reference/repos#remove-app-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/apps"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_teams_with_access_to_the_protected_branch(self, owner, repo, branch, payload=None):
        """
        Get teams with access to the protected branch
        https://docs.github.com/rest/reference/repos#list-teams-with-access-to-the-protected-branch
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/teams"
        )
        response = self._execute("get", url, payload)
        return response

    def add_team_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Add team access restrictions
        https://docs.github.com/rest/reference/repos#add-team-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/teams"
        )
        response = self._execute("post", url, payload)
        return response

    def set_team_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Set team access restrictions
        https://docs.github.com/rest/reference/repos#set-team-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/teams"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_team_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Remove team access restrictions
        https://docs.github.com/rest/reference/repos#remove-team-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/teams"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_users_with_access_to_the_protected_branch(self, owner, repo, branch, payload=None):
        """
        Get users with access to the protected branch
        https://docs.github.com/rest/reference/repos#list-users-with-access-to-the-protected-branch
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/users"
        )
        response = self._execute("get", url, payload)
        return response

    def add_user_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Add user access restrictions
        https://docs.github.com/rest/reference/repos#add-user-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/users"
        )
        response = self._execute("post", url, payload)
        return response

    def set_user_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Set user access restrictions
        https://docs.github.com/rest/reference/repos#set-user-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/users"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_user_access_restrictions(self, owner, repo, branch, payload=None):
        """
        Remove user access restrictions
        https://docs.github.com/rest/reference/repos#remove-user-access-restrictions
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/branches/{branch}/protection/restrictions/users"
        )
        response = self._execute("delete", url, payload)
        return response

    def rename_a_branch(self, owner, repo, branch, payload=None):
        """
        Rename a branch
        https://docs.github.com/rest/reference/repos#rename-a-branch
        Attributes:
        Path Parameters:
        owner
        repo
        branch
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/branches/{branch}/rename"
        response = self._execute("post", url, payload)
        return response

    def list_codeowners_errors(self, owner, repo, payload=None):
        """
        List CODEOWNERS errors
        https://docs.github.com/rest/reference/repos#list-codeowners-errors
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        ref
        """
        url = self._base_url + f"/repos/{owner}/{repo}/codeowners/errors"
        response = self._execute("get", url, payload)
        return response

    def list_repository_collaborators(self, owner, repo, payload=None):
        """
        List repository collaborators
        https://docs.github.com/rest/reference/repos#list-repository-collaborators
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        affiliation
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/collaborators"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_user_is_a_repository_collaborator(self, owner, repo, username, payload=None):
        """
        Check if a user is a repository collaborator
        https://docs.github.com/rest/reference/repos#check-if-a-user-is-a-repository-collaborator
        Attributes:
        Path Parameters:
        owner
        repo
        username
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/collaborators/{username}"
        response = self._execute("get", url, payload)
        return response

    def add_a_repository_collaborator(self, owner, repo, username, payload=None):
        """
        Add a repository collaborator
        https://docs.github.com/rest/reference/repos#add-a-repository-collaborator
        Attributes:
        Path Parameters:
        owner
        repo
        username
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/collaborators/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_a_repository_collaborator(self, owner, repo, username, payload=None):
        """
        Remove a repository collaborator
        https://docs.github.com/rest/reference/repos#remove-a-repository-collaborator
        Attributes:
        Path Parameters:
        owner
        repo
        username
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/collaborators/{username}"
        response = self._execute("delete", url, payload)
        return response

    def get_repository_permissions_for_a_user(self, owner, repo, username, payload=None):
        """
        Get repository permissions for a user
        https://docs.github.com/rest/reference/repos#get-repository-permissions-for-a-user
        Attributes:
        Path Parameters:
        owner
        repo
        username
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/collaborators/{username}/permission"
        response = self._execute("get", url, payload)
        return response

    def list_commit_comments_for_a_repository(self, owner, repo, payload=None):
        """
        List commit comments for a repository
        https://docs.github.com/rest/reference/repos#list-commit-comments-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/comments"
        response = self._execute("get", url, payload)
        return response

    def get_a_commit_comment(self, owner, repo, comment_id, payload=None):
        """
        Get a commit comment
        https://docs.github.com/rest/reference/repos#get-a-commit-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_commit_comment(self, owner, repo, comment_id, payload=None):
        """
        Update a commit comment
        https://docs.github.com/rest/reference/repos#update-a-commit-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_commit_comment(self, owner, repo, comment_id, payload=None):
        """
        Delete a commit comment
        https://docs.github.com/rest/reference/repos#delete-a-commit-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_commits(self, owner, repo, payload=None):
        """
        List commits
        https://docs.github.com/rest/reference/repos#list-commits
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        sha
         path
         author
         since
         until
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits"
        response = self._execute("get", url, payload)
        return response

    def list_branches_for_head_commit(self, owner, repo, commit_sha, payload=None):
        """
        List branches for HEAD commit
        https://docs.github.com/rest/reference/repos#list-branches-for-head-commit
        Attributes:
        Path Parameters:
        owner
        repo
        commit_sha
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{commit_sha}/branches-where-head"
        response = self._execute("get", url, payload)
        return response

    def list_commit_comments(self, owner, repo, commit_sha, payload=None):
        """
        List commit comments
        https://docs.github.com/rest/reference/repos#list-commit-comments
        Attributes:
        Path Parameters:
        owner
        repo
        commit_sha
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{commit_sha}/comments"
        response = self._execute("get", url, payload)
        return response

    def create_a_commit_comment(self, owner, repo, commit_sha, payload=None):
        """
        Create a commit comment
        https://docs.github.com/rest/reference/repos#create-a-commit-comment
        Attributes:
        Path Parameters:
        owner
        repo
        commit_sha
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{commit_sha}/comments"
        response = self._execute("post", url, payload)
        return response

    def list_pull_requests_associated_with_a_commit(self, owner, repo, commit_sha, payload=None):
        """
        List pull requests associated with a commit
        https://docs.github.com/rest/reference/repos#list-pull-requests-associated-with-a-commit
        Attributes:
        Path Parameters:
        owner
        repo
        commit_sha
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{commit_sha}/pulls"
        response = self._execute("get", url, payload)
        return response

    def get_a_commit(self, owner, repo, ref, payload=None):
        """
        Get a commit
        https://docs.github.com/rest/reference/repos#get-a-commit
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:
        page
         per-page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{ref}"
        response = self._execute("get", url, payload)
        return response

    def get_the_combined_status_for_a_specific_reference(self, owner, repo, ref, payload=None):
        """
        Get the combined status for a specific reference
        https://docs.github.com/rest/reference/repos#get-the-combined-status-for-a-specific-reference
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{ref}/status"
        response = self._execute("get", url, payload)
        return response

    def list_commit_statuses_for_a_reference(self, owner, repo, ref, payload=None):
        """
        List commit statuses for a reference
        https://docs.github.com/rest/reference/repos#list-commit-statuses-for-a-reference
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{ref}/statuses"
        response = self._execute("get", url, payload)
        return response

    def get_community_profile_metrics(self, owner, repo, payload=None):
        """
        Get community profile metrics
        https://docs.github.com/rest/reference/repos#get-community-profile-metrics
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/community/profile"
        response = self._execute("get", url, payload)
        return response

    def compare_two_commits(self, owner, repo, basehead, payload=None):
        """
        Compare two commits
        https://docs.github.com/rest/reference/repos#compare-two-commits
        Attributes:
        Path Parameters:
        owner
        repo
        basehead
        Payload Parameters:
        page
         per-page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/compare/{basehead}"
        response = self._execute("get", url, payload)
        return response

    def get_repository_content(self, owner, repo, path, payload=None):
        """
        Get repository content
        https://docs.github.com/rest/reference/repos#get-repository-content
        Attributes:
        Path Parameters:
        owner
        repo
        path
        Payload Parameters:
        ref
        """
        url = self._base_url + f"/repos/{owner}/{repo}/contents/{path}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_file_contents(self, owner, repo, path, payload=None):
        """
        Create or update file contents
        https://docs.github.com/rest/reference/repos#create-or-update-file-contents
        Attributes:
        Path Parameters:
        owner
        repo
        path
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/contents/{path}"
        response = self._execute("put", url, payload)
        return response

    def delete_a_file(self, owner, repo, path, payload=None):
        """
        Delete a file
        https://docs.github.com/rest/reference/repos#delete-a-file
        Attributes:
        Path Parameters:
        owner
        repo
        path
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/contents/{path}"
        response = self._execute("delete", url, payload)
        return response

    def list_repository_contributors(self, owner, repo, payload=None):
        """
        List repository contributors
        https://docs.github.com/rest/reference/repos#list-repository-contributors
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        anon
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/contributors"
        response = self._execute("get", url, payload)
        return response

    def list_deployments(self, owner, repo, payload=None):
        """
        List deployments
        https://docs.github.com/rest/reference/repos#list-deployments
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        sha
         ref
         task
         environment
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/deployments"
        response = self._execute("get", url, payload)
        return response

    def create_a_deployment(self, owner, repo, payload=None):
        """
        Create a deployment
        https://docs.github.com/rest/reference/repos#create-a-deployment
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/deployments"
        response = self._execute("post", url, payload)
        return response

    def get_a_deployment(self, owner, repo, deployment_id, payload=None):
        """
        Get a deployment
        https://docs.github.com/rest/reference/repos#get-a-deployment
        Attributes:
        Path Parameters:
        owner
        repo
        deployment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/deployments/{deployment_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_deployment(self, owner, repo, deployment_id, payload=None):
        """
        Delete a deployment
        https://docs.github.com/rest/reference/repos#delete-a-deployment
        Attributes:
        Path Parameters:
        owner
        repo
        deployment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/deployments/{deployment_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_deployment_statuses(self, owner, repo, deployment_id, payload=None):
        """
        List deployment statuses
        https://docs.github.com/rest/reference/repos#list-deployment-statuses
        Attributes:
        Path Parameters:
        owner
        repo
        deployment_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/deployments/{deployment_id}/statuses"
        response = self._execute("get", url, payload)
        return response

    def create_a_deployment_status(self, owner, repo, deployment_id, payload=None):
        """
        Create a deployment status
        https://docs.github.com/rest/reference/repos#create-a-deployment-status
        Attributes:
        Path Parameters:
        owner
        repo
        deployment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/deployments/{deployment_id}/statuses"
        response = self._execute("post", url, payload)
        return response

    def get_a_deployment_status(
        self, owner, repo, deployment_id, status_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Get a deployment status
        https://docs.github.com/rest/reference/repos#get-a-deployment-status
        Attributes:
        Path Parameters:
        owner
        repo
        deployment_id
        status_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/deployments/{deployment_id}/statuses/{status_id}"
        )
        response = self._execute("get", url, payload)
        return response

    def create_a_repository_dispatch_event(self, owner, repo, payload=None):
        """
        Create a repository dispatch event
        https://docs.github.com/rest/reference/repos#create-a-repository-dispatch-event
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/dispatches"
        response = self._execute("post", url, payload)
        return response

    def get_all_environments(self, owner, repo, payload=None):
        """
        Get all environments
        https://docs.github.com/rest/reference/repos#get-all-environments
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/environments"
        response = self._execute("get", url, payload)
        return response

    def get_an_environment(self, owner, repo, environment_name, payload=None):
        """
        Get an environment
        https://docs.github.com/rest/reference/repos#get-an-environment
        Attributes:
        Path Parameters:
        owner
        repo
        environment_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/environments/{environment_name}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_an_environment(self, owner, repo, environment_name, payload=None):
        """
        Create or update an environment
        https://docs.github.com/rest/reference/repos#create-or-update-an-environment
        Attributes:
        Path Parameters:
        owner
        repo
        environment_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/environments/{environment_name}"
        response = self._execute("put", url, payload)
        return response

    def delete_an_environment(self, owner, repo, environment_name, payload=None):
        """
        Delete an environment
        https://docs.github.com/rest/reference/repos#delete-an-environment
        Attributes:
        Path Parameters:
        owner
        repo
        environment_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/environments/{environment_name}"
        response = self._execute("delete", url, payload)
        return response

    def list_forks(self, owner, repo, payload=None):
        """
        List forks
        https://docs.github.com/rest/reference/repos#list-forks
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        sort
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/forks"
        response = self._execute("get", url, payload)
        return response

    def create_a_fork(self, owner, repo, payload=None):
        """
        Create a fork
        https://docs.github.com/rest/reference/repos#create-a-fork
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/forks"
        response = self._execute("post", url, payload)
        return response

    def list_repository_webhooks(self, owner, repo, payload=None):
        """
        List repository webhooks
        https://docs.github.com/rest/reference/repos#list-repository-webhooks
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks"
        response = self._execute("get", url, payload)
        return response

    def create_a_repository_webhook(self, owner, repo, payload=None):
        """
        Create a repository webhook
        https://docs.github.com/rest/reference/repos#create-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks"
        response = self._execute("post", url, payload)
        return response

    def get_a_repository_webhook(self, owner, repo, hook_id, payload=None):
        """
        Get a repository webhook
        https://docs.github.com/rest/reference/repos#get-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_repository_webhook(self, owner, repo, hook_id, payload=None):
        """
        Update a repository webhook
        https://docs.github.com/rest/reference/repos#update-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_repository_webhook(self, owner, repo, hook_id, payload=None):
        """
        Delete a repository webhook
        https://docs.github.com/rest/reference/repos#delete-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}"
        response = self._execute("delete", url, payload)
        return response

    def get_a_webhook_configuration_for_a_repository(self, owner, repo, hook_id, payload=None):
        """
        Get a webhook configuration for a repository
        https://docs.github.com/rest/reference/repos#get-a-webhook-configuration-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}/config"
        response = self._execute("get", url, payload)
        return response

    def update_a_webhook_configuration_for_a_repository(self, owner, repo, hook_id, payload=None):
        """
        Update a webhook configuration for a repository
        https://docs.github.com/rest/reference/repos#update-a-webhook-configuration-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}/config"
        response = self._execute("patch", url, payload)
        return response

    def list_deliveries_for_a_repository_webhook(self, owner, repo, hook_id, payload=None):
        """
        List deliveries for a repository webhook
        https://docs.github.com/rest/reference/repos#list-deliveries-for-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:
        per-page
         cursor
        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}/deliveries"
        response = self._execute("get", url, payload)
        return response

    def get_a_delivery_for_a_repository_webhook(
        self, owner, repo, hook_id, delivery_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Get a delivery for a repository webhook
        https://docs.github.com/rest/reference/repos#get-a-delivery-for-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        delivery_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}/deliveries/{delivery_id}"
        response = self._execute("get", url, payload)
        return response

    def redeliver_a_delivery_for_a_repository_webhook(
        self, owner, repo, hook_id, delivery_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Redeliver a delivery for a repository webhook
        https://docs.github.com/rest/reference/repos#redeliver-a-delivery-for-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        delivery_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/hooks/{hook_id}/deliveries/{delivery_id}/attempts"
        )
        response = self._execute("post", url, payload)
        return response

    def ping_a_repository_webhook(self, owner, repo, hook_id, payload=None):
        """
        Ping a repository webhook
        https://docs.github.com/rest/reference/repos#ping-a-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}/pings"
        response = self._execute("post", url, payload)
        return response

    def test_the_push_repository_webhook(self, owner, repo, hook_id, payload=None):
        """
        Test the push repository webhook
        https://docs.github.com/rest/reference/repos#test-the-push-repository-webhook
        Attributes:
        Path Parameters:
        owner
        repo
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/hooks/{hook_id}/tests"
        response = self._execute("post", url, payload)
        return response

    def list_repository_invitations(self, owner, repo, payload=None):
        """
        List repository invitations
        https://docs.github.com/rest/reference/repos#list-repository-invitations
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/invitations"
        response = self._execute("get", url, payload)
        return response

    def update_a_repository_invitation(self, owner, repo, invitation_id, payload=None):
        """
        Update a repository invitation
        https://docs.github.com/rest/reference/repos#update-a-repository-invitation
        Attributes:
        Path Parameters:
        owner
        repo
        invitation_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/invitations/{invitation_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_repository_invitation(self, owner, repo, invitation_id, payload=None):
        """
        Delete a repository invitation
        https://docs.github.com/rest/reference/repos#delete-a-repository-invitation
        Attributes:
        Path Parameters:
        owner
        repo
        invitation_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/invitations/{invitation_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_deploy_keys(self, owner, repo, payload=None):
        """
        List deploy keys
        https://docs.github.com/rest/reference/repos#list-deploy-keys
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/keys"
        response = self._execute("get", url, payload)
        return response

    def create_a_deploy_key(self, owner, repo, payload=None):
        """
        Create a deploy key
        https://docs.github.com/rest/reference/repos#create-a-deploy-key
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/keys"
        response = self._execute("post", url, payload)
        return response

    def get_a_deploy_key(self, owner, repo, key_id, payload=None):
        """
        Get a deploy key
        https://docs.github.com/rest/reference/repos#get-a-deploy-key
        Attributes:
        Path Parameters:
        owner
        repo
        key_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/keys/{key_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_deploy_key(self, owner, repo, key_id, payload=None):
        """
        Delete a deploy key
        https://docs.github.com/rest/reference/repos#delete-a-deploy-key
        Attributes:
        Path Parameters:
        owner
        repo
        key_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/keys/{key_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_repository_languages(self, owner, repo, payload=None):
        """
        List repository languages
        https://docs.github.com/rest/reference/repos#list-repository-languages
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/languages"
        response = self._execute("get", url, payload)
        return response

    def enable_git_lfs_for_a_repository(self, owner, repo, payload=None):
        """
        Enable Git LFS for a repository
        https://docs.github.com/rest/reference/repos#enable-git-lfs-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/lfs"
        response = self._execute("put", url, payload)
        return response

    def disable_git_lfs_for_a_repository(self, owner, repo, payload=None):
        """
        Disable Git LFS for a repository
        https://docs.github.com/rest/reference/repos#disable-git-lfs-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/lfs"
        response = self._execute("delete", url, payload)
        return response

    def sync_a_fork_branch_with_the_upstream_repository(self, owner, repo, payload=None):
        """
        Sync a fork branch with the upstream repository
        https://docs.github.com/rest/reference/repos#sync-a-fork-branch-with-the-upstream-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/merge-upstream"
        response = self._execute("post", url, payload)
        return response

    def merge_a_branch(self, owner, repo, payload=None):
        """
        Merge a branch
        https://docs.github.com/rest/reference/repos#merge-a-branch
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/merges"
        response = self._execute("post", url, payload)
        return response

    def get_a_github_pages_site(self, owner, repo, payload=None):
        """
        Get a GitHub Pages site
        https://docs.github.com/rest/reference/repos#get-a-github-pages-site
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages"
        response = self._execute("get", url, payload)
        return response

    def create_a_github_pages_site(self, owner, repo, payload=None):
        """
        Create a GitHub Pages site
        https://docs.github.com/rest/reference/repos#create-a-github-pages-site
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages"
        response = self._execute("post", url, payload)
        return response

    def update_information_about_a_github_pages_site(self, owner, repo, payload=None):
        """
        Update information about a GitHub Pages site
        https://docs.github.com/rest/reference/repos#update-information-about-a-github-pages-site
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages"
        response = self._execute("put", url, payload)
        return response

    def delete_a_github_pages_site(self, owner, repo, payload=None):
        """
        Delete a GitHub Pages site
        https://docs.github.com/rest/reference/repos#delete-a-github-pages-site
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages"
        response = self._execute("delete", url, payload)
        return response

    def list_github_pages_builds(self, owner, repo, payload=None):
        """
        List GitHub Pages builds
        https://docs.github.com/rest/reference/repos#list-github-pages-builds
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages/builds"
        response = self._execute("get", url, payload)
        return response

    def request_a_github_pages_build(self, owner, repo, payload=None):
        """
        Request a GitHub Pages build
        https://docs.github.com/rest/reference/repos#request-a-github-pages-build
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages/builds"
        response = self._execute("post", url, payload)
        return response

    def get_latest_pages_build(self, owner, repo, payload=None):
        """
        Get latest Pages build
        https://docs.github.com/rest/reference/repos#get-latest-pages-build
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages/builds/latest"
        response = self._execute("get", url, payload)
        return response

    def get_github_pages_build(self, owner, repo, build_id, payload=None):
        """
        Get GitHub Pages build
        https://docs.github.com/rest/reference/repos#get-github-pages-build
        Attributes:
        Path Parameters:
        owner
        repo
        build_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages/builds/{build_id}"
        response = self._execute("get", url, payload)
        return response

    def create_a_github_pages_deployment(self, owner, repo, payload=None):
        """
        Create a GitHub Pages deployment
        https://docs.github.com/rest/reference/repos#create-a-github-pages-deployment
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages/deployment"
        response = self._execute("post", url, payload)
        return response

    def get_a_dns_health_check_for_github_pages(self, owner, repo, payload=None):
        """
        Get a DNS health check for GitHub Pages
        https://docs.github.com/rest/reference/repos#get-a-dns-health-check-for-github-pages
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pages/health"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_readme(self, owner, repo, payload=None):
        """
        Get a repository README
        https://docs.github.com/rest/reference/repos#get-a-repository-readme
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        ref
        """
        url = self._base_url + f"/repos/{owner}/{repo}/readme"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_readme_for_a_directory(self, owner, repo, directory, payload=None):
        """
        Get a repository README for a directory
        https://docs.github.com/rest/reference/repos#get-a-repository-directory-readme
        Attributes:
        Path Parameters:
        owner
        repo
        directory
        Payload Parameters:
        ref
        """
        url = self._base_url + f"/repos/{owner}/{repo}/readme/{directory}"
        response = self._execute("get", url, payload)
        return response

    def list_releases(self, owner, repo, payload=None):
        """
        List releases
        https://docs.github.com/rest/reference/repos#list-releases
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases"
        response = self._execute("get", url, payload)
        return response

    def create_a_release(self, owner, repo, payload=None):
        """
        Create a release
        https://docs.github.com/rest/reference/repos#create-a-release
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases"
        response = self._execute("post", url, payload)
        return response

    def get_a_release_asset(self, owner, repo, asset_id, payload=None):
        """
        Get a release asset
        https://docs.github.com/rest/reference/repos#get-a-release-asset
        Attributes:
        Path Parameters:
        owner
        repo
        asset_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/assets/{asset_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_release_asset(self, owner, repo, asset_id, payload=None):
        """
        Update a release asset
        https://docs.github.com/rest/reference/repos#update-a-release-asset
        Attributes:
        Path Parameters:
        owner
        repo
        asset_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/assets/{asset_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_release_asset(self, owner, repo, asset_id, payload=None):
        """
        Delete a release asset
        https://docs.github.com/rest/reference/repos#delete-a-release-asset
        Attributes:
        Path Parameters:
        owner
        repo
        asset_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/assets/{asset_id}"
        response = self._execute("delete", url, payload)
        return response

    def generate_release_notes_content_for_a_release(self, owner, repo, payload=None):
        """
        Generate release notes content for a release
        https://docs.github.com/rest/reference/repos#generate-release-notes
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/generate-notes"
        response = self._execute("post", url, payload)
        return response

    def get_the_latest_release(self, owner, repo, payload=None):
        """
        Get the latest release
        https://docs.github.com/rest/reference/repos#get-the-latest-release
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/latest"
        response = self._execute("get", url, payload)
        return response

    def get_a_release_by_tag_name(self, owner, repo, tag, payload=None):
        """
        Get a release by tag name
        https://docs.github.com/rest/reference/repos#get-a-release-by-tag-name
        Attributes:
        Path Parameters:
        owner
        repo
        tag
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/tags/{tag}"
        response = self._execute("get", url, payload)
        return response

    def get_a_release(self, owner, repo, release_id, payload=None):
        """
        Get a release
        https://docs.github.com/rest/reference/repos#get-a-release
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_release(self, owner, repo, release_id, payload=None):
        """
        Update a release
        https://docs.github.com/rest/reference/repos#update-a-release
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_release(self, owner, repo, release_id, payload=None):
        """
        Delete a release
        https://docs.github.com/rest/reference/repos#delete-a-release
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_release_assets(self, owner, repo, release_id, payload=None):
        """
        List release assets
        https://docs.github.com/rest/reference/repos#list-release-assets
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/assets"
        response = self._execute("get", url, payload)
        return response

    def upload_a_release_asset(self, owner, repo, release_id, payload=None):
        """
        Upload a release asset
        https://docs.github.com/rest/reference/repos#upload-a-release-asset
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        Payload Parameters:
        name
         label
        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/assets"
        response = self._execute("post", url, payload)
        return response

    def get_the_weekly_commit_activity(self, owner, repo, payload=None):
        """
        Get the weekly commit activity
        https://docs.github.com/rest/reference/repos#get-the-weekly-commit-activity
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/stats/code_frequency"
        response = self._execute("get", url, payload)
        return response

    def get_the_last_year_of_commit_activity(self, owner, repo, payload=None):
        """
        Get the last year of commit activity
        https://docs.github.com/rest/reference/repos#get-the-last-year-of-commit-activity
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/stats/commit_activity"
        response = self._execute("get", url, payload)
        return response

    def get_all_contributor_commit_activity(self, owner, repo, payload=None):
        """
        Get all contributor commit activity
        https://docs.github.com/rest/reference/repos#get-all-contributor-commit-activity
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/stats/contributors"
        response = self._execute("get", url, payload)
        return response

    def get_the_weekly_commit_count(self, owner, repo, payload=None):
        """
        Get the weekly commit count
        https://docs.github.com/rest/reference/repos#get-the-weekly-commit-count
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/stats/participation"
        response = self._execute("get", url, payload)
        return response

    def get_the_hourly_commit_count_for_each_day(self, owner, repo, payload=None):
        """
        Get the hourly commit count for each day
        https://docs.github.com/rest/reference/repos#get-the-hourly-commit-count-for-each-day
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/stats/punch_card"
        response = self._execute("get", url, payload)
        return response

    def create_a_commit_status(self, owner, repo, sha, payload=None):
        """
        Create a commit status
        https://docs.github.com/rest/reference/repos#create-a-commit-status
        Attributes:
        Path Parameters:
        owner
        repo
        sha
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/statuses/{sha}"
        response = self._execute("post", url, payload)
        return response

    def list_repository_tags(self, owner, repo, payload=None):
        """
        List repository tags
        https://docs.github.com/rest/reference/repos#list-repository-tags
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/tags"
        response = self._execute("get", url, payload)
        return response

    def list_tag_protection_states_for_a_repository(self, owner, repo, payload=None):
        """
        List tag protection states for a repository
        https://docs.github.com/rest/reference/repos#list-tag-protection-state-of-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/tags/protection"
        response = self._execute("get", url, payload)
        return response

    def create_a_tag_protection_state_for_a_repository(self, owner, repo, payload=None):
        """
        Create a tag protection state for a repository
        https://docs.github.com/rest/reference/repos#create-tag-protection-state-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/tags/protection"
        response = self._execute("post", url, payload)
        return response

    def delete_a_tag_protection_state_for_a_repository(
        self, owner, repo, tag_protection_id, payload=None
    ):
        """
        Delete a tag protection state for a repository
        https://docs.github.com/rest/reference/repos#delete-tag-protection-state-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        tag_protection_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/tags/protection/{tag_protection_id}"
        response = self._execute("delete", url, payload)
        return response

    def download_a_repository_archive__tar(self, owner, repo, ref, payload=None):
        """
        Download a repository archive (tar)
        https://docs.github.com/rest/reference/repos#download-a-repository-archive
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/tarball/{ref}"
        response = self._execute("get", url, payload)
        return response

    def list_repository_teams(self, owner, repo, payload=None):
        """
        List repository teams
        https://docs.github.com/rest/reference/repos#list-repository-teams
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/teams"
        response = self._execute("get", url, payload)
        return response

    def get_all_repository_topics(self, owner, repo, payload=None):
        """
        Get all repository topics
        https://docs.github.com/rest/reference/repos#get-all-repository-topics
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        page
         per-page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/topics"
        response = self._execute("get", url, payload)
        return response

    def replace_all_repository_topics(self, owner, repo, payload=None):
        """
        Replace all repository topics
        https://docs.github.com/rest/reference/repos#replace-all-repository-topics
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/topics"
        response = self._execute("put", url, payload)
        return response

    def get_repository_clones(self, owner, repo, payload=None):
        """
        Get repository clones
        https://docs.github.com/rest/reference/repos#get-repository-clones
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per
        """
        url = self._base_url + f"/repos/{owner}/{repo}/traffic/clones"
        response = self._execute("get", url, payload)
        return response

    def get_top_referral_paths(self, owner, repo, payload=None):
        """
        Get top referral paths
        https://docs.github.com/rest/reference/repos#get-top-referral-paths
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/traffic/popular/paths"
        response = self._execute("get", url, payload)
        return response

    def get_top_referral_sources(self, owner, repo, payload=None):
        """
        Get top referral sources
        https://docs.github.com/rest/reference/repos#get-top-referral-sources
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/traffic/popular/referrers"
        response = self._execute("get", url, payload)
        return response

    def get_page_views(self, owner, repo, payload=None):
        """
        Get page views
        https://docs.github.com/rest/reference/repos#get-page-views
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per
        """
        url = self._base_url + f"/repos/{owner}/{repo}/traffic/views"
        response = self._execute("get", url, payload)
        return response

    def transfer_a_repository(self, owner, repo, payload=None):
        """
        Transfer a repository
        https://docs.github.com/rest/reference/repos#transfer-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/transfer"
        response = self._execute("post", url, payload)
        return response

    def check_if_vulnerability_alerts_are_enabled_for_a_repository(self, owner, repo, payload=None):
        """
        Check if vulnerability alerts are enabled for a repository
        https://docs.github.com/rest/reference/repos#check-if-vulnerability-alerts-are-enabled-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/vulnerability-alerts"
        response = self._execute("get", url, payload)
        return response

    def enable_vulnerability_alerts(self, owner, repo, payload=None):
        """
        Enable vulnerability alerts
        https://docs.github.com/rest/reference/repos#enable-vulnerability-alerts
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/vulnerability-alerts"
        response = self._execute("put", url, payload)
        return response

    def disable_vulnerability_alerts(self, owner, repo, payload=None):
        """
        Disable vulnerability alerts
        https://docs.github.com/rest/reference/repos#disable-vulnerability-alerts
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/vulnerability-alerts"
        response = self._execute("delete", url, payload)
        return response

    def download_a_repository_archive__zip(self, owner, repo, ref, payload=None):
        """
        Download a repository archive (zip)
        https://docs.github.com/rest/reference/repos#download-a-repository-archive
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/zipball/{ref}"
        response = self._execute("get", url, payload)
        return response

    def create_a_repository_using_a_template(self, template_owner, template_repo, payload=None):
        """
        Create a repository using a template
        https://docs.github.com/rest/reference/repos#create-a-repository-using-a-template
        Attributes:
        Path Parameters:
        template_owner
        template_repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{template_owner}/{template_repo}/generate"
        response = self._execute("post", url, payload)
        return response

    def list_public_repositories(self, payload=None):
        """
        List public repositories
        https://docs.github.com/rest/reference/repos#list-public-repositories
        Attributes:
        Path Parameters:

        Payload Parameters:
        since-repo
        """
        url = self._base_url + "/repositories"
        response = self._execute("get", url, payload)
        return response

    def report_telemetry_back_to_datadog(self, repository_id, payload=None):
        """
        Report telemetry back to datadog
        https://docs.github.com/rest/reference/repos#report-telemetry-back-to-datadog
        Attributes:
        Path Parameters:
        repository_id
        Payload Parameters:

        """
        url = self._base_url + f"/repositories/{repository_id}/pages/telemetry"
        response = self._execute("post", url, payload)
        return response

    def list_repositories_for_the_authenticated_user(self, payload=None):
        """
        List repositories for the authenticated user
        https://docs.github.com/rest/reference/repos#list-repositories-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        visibility
         affiliation
         type
         sort
         direction
         per-page
         page
         since
         before
        """
        url = self._base_url + "/user/repos"
        response = self._execute("get", url, payload)
        return response

    def create_a_repository_for_the_authenticated_user(self, payload=None):
        """
        Create a repository for the authenticated user
        https://docs.github.com/rest/reference/repos#create-a-repository-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/repos"
        response = self._execute("post", url, payload)
        return response

    def list_repository_invitations_for_the_authenticated_user(self, payload=None):
        """
        List repository invitations for the authenticated user
        https://docs.github.com/rest/reference/repos#list-repository-invitations-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/repository_invitations"
        response = self._execute("get", url, payload)
        return response

    def accept_a_repository_invitation(self, invitation_id, payload=None):
        """
        Accept a repository invitation
        https://docs.github.com/rest/reference/repos#accept-a-repository-invitation
        Attributes:
        Path Parameters:
        invitation_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/repository_invitations/{invitation_id}"
        response = self._execute("patch", url, payload)
        return response

    def decline_a_repository_invitation(self, invitation_id, payload=None):
        """
        Decline a repository invitation
        https://docs.github.com/rest/reference/repos#decline-a-repository-invitation
        Attributes:
        Path Parameters:
        invitation_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/repository_invitations/{invitation_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_repositories_for_a_user(self, username, payload=None):
        """
        List repositories for a user
        https://docs.github.com/rest/reference/repos#list-repositories-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        type
         sort
         direction
         per-page
         page
        """
        url = self._base_url + f"/users/{username}/repos"
        response = self._execute("get", url, payload)
        return response



"""
View, modify your gists.
"""


class Gists:
    """
    View, modify your gists.
    """

    def __init__(self, client):
        """
        Initialize the Gists class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_gists_for_the_authenticated_user(self, payload=None):
        """
        List gists for the authenticated user
        https://docs.github.com/rest/reference/gists#list-gists-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        since
         per-page
         page
        """
        url = self._base_url + "/gists"
        response = self._execute("get", url, payload)
        return response

    def create_a_gist(self, payload=None):
        """
        Create a gist
        https://docs.github.com/rest/reference/gists#create-a-gist
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/gists"
        response = self._execute("post", url, payload)
        return response

    def list_public_gists(self, payload=None):
        """
        List public gists
        https://docs.github.com/rest/reference/gists#list-public-gists
        Attributes:
        Path Parameters:

        Payload Parameters:
        since
         per-page
         page
        """
        url = self._base_url + "/gists/public"
        response = self._execute("get", url, payload)
        return response

    def list_starred_gists(self, payload=None):
        """
        List starred gists
        https://docs.github.com/rest/reference/gists#list-starred-gists
        Attributes:
        Path Parameters:

        Payload Parameters:
        since
         per-page
         page
        """
        url = self._base_url + "/gists/starred"
        response = self._execute("get", url, payload)
        return response

    def get_a_gist(self, gist_id, payload=None):
        """
        Get a gist
        https://docs.github.com/rest/reference/gists#get-a-gist
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_gist(self, gist_id, payload=None):
        """
        Update a gist
        https://docs.github.com/rest/reference/gists/#update-a-gist
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_gist(self, gist_id, payload=None):
        """
        Delete a gist
        https://docs.github.com/rest/reference/gists#delete-a-gist
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_gist_comments(self, gist_id, payload=None):
        """
        List gist comments
        https://docs.github.com/rest/reference/gists#list-gist-comments
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/gists/{gist_id}/comments"
        response = self._execute("get", url, payload)
        return response

    def create_a_gist_comment(self, gist_id, payload=None):
        """
        Create a gist comment
        https://docs.github.com/rest/reference/gists#create-a-gist-comment
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/comments"
        response = self._execute("post", url, payload)
        return response

    def get_a_gist_comment(self, gist_id, comment_id, payload=None):
        """
        Get a gist comment
        https://docs.github.com/rest/reference/gists#get-a-gist-comment
        Attributes:
        Path Parameters:
        gist_id
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/comments/{comment_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_gist_comment(self, gist_id, comment_id, payload=None):
        """
        Update a gist comment
        https://docs.github.com/rest/reference/gists#update-a-gist-comment
        Attributes:
        Path Parameters:
        gist_id
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/comments/{comment_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_gist_comment(self, gist_id, comment_id, payload=None):
        """
        Delete a gist comment
        https://docs.github.com/rest/reference/gists#delete-a-gist-comment
        Attributes:
        Path Parameters:
        gist_id
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/comments/{comment_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_gist_commits(self, gist_id, payload=None):
        """
        List gist commits
        https://docs.github.com/rest/reference/gists#list-gist-commits
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/gists/{gist_id}/commits"
        response = self._execute("get", url, payload)
        return response

    def list_gist_forks(self, gist_id, payload=None):
        """
        List gist forks
        https://docs.github.com/rest/reference/gists#list-gist-forks
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/gists/{gist_id}/forks"
        response = self._execute("get", url, payload)
        return response

    def fork_a_gist(self, gist_id, payload=None):
        """
        Fork a gist
        https://docs.github.com/rest/reference/gists#fork-a-gist
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/forks"
        response = self._execute("post", url, payload)
        return response

    def check_if_a_gist_is_starred(self, gist_id, payload=None):
        """
        Check if a gist is starred
        https://docs.github.com/rest/reference/gists#check-if-a-gist-is-starred
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/star"
        response = self._execute("get", url, payload)
        return response

    def star_a_gist(self, gist_id, payload=None):
        """
        Star a gist
        https://docs.github.com/rest/reference/gists#star-a-gist
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/star"
        response = self._execute("put", url, payload)
        return response

    def unstar_a_gist(self, gist_id, payload=None):
        """
        Unstar a gist
        https://docs.github.com/rest/reference/gists#unstar-a-gist
        Attributes:
        Path Parameters:
        gist_id
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/star"
        response = self._execute("delete", url, payload)
        return response

    def get_a_gist_revision(self, gist_id, sha, payload=None):
        """
        Get a gist revision
        https://docs.github.com/rest/reference/gists#get-a-gist-revision
        Attributes:
        Path Parameters:
        gist_id
        sha
        Payload Parameters:

        """
        url = self._base_url + f"/gists/{gist_id}/{sha}"
        response = self._execute("get", url, payload)
        return response

    def list_gists_for_a_user(self, username, payload=None):
        """
        List gists for a user
        https://docs.github.com/rest/reference/gists#list-gists-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        since
         per-page
         page
        """
        url = self._base_url + f"/users/{username}/gists"
        response = self._execute("get", url, payload)
        return response



"""
Retrieve secret scanning alerts from a repository.
"""


class SecretScanning:
    """
    Retrieve secret scanning alerts from a repository.
    """

    def __init__(self, client):
        """
        Initialize the SecretScanning class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_secret_scanning_alerts_for_an_enterprise(self, enterprise, payload=None):
        """
        List secret scanning alerts for an enterprise
        https://docs.github.com/rest/reference/secret-scanning#list-secret-scanning-alerts-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        secret-scanning-alert-state
         secret-scanning-alert-secret-type
         secret-scanning-alert-resolution
         secret-scanning-alert-sort
         direction
         per-page
         pagination-before
         pagination-after
        """
        url = self._base_url + f"/enterprises/{enterprise}/secret-scanning/alerts"
        response = self._execute("get", url, payload)
        return response

    def list_secret_scanning_alerts_for_an_organization(self, org, payload=None):
        """
        List secret scanning alerts for an organization
        https://docs.github.com/rest/reference/secret-scanning#list-secret-scanning-alerts-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        secret-scanning-alert-state
         secret-scanning-alert-secret-type
         secret-scanning-alert-resolution
         secret-scanning-alert-sort
         direction
         page
         per-page
         secret-scanning-pagination-before-org-repo
         secret-scanning-pagination-after-org-repo
        """
        url = self._base_url + f"/orgs/{org}/secret-scanning/alerts"
        response = self._execute("get", url, payload)
        return response

    def list_secret_scanning_alerts_for_a_repository(self, owner, repo, payload=None):
        """
        List secret scanning alerts for a repository
        https://docs.github.com/rest/reference/secret-scanning#list-secret-scanning-alerts-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        secret-scanning-alert-state
         secret-scanning-alert-secret-type
         secret-scanning-alert-resolution
         secret-scanning-alert-sort
         direction
         page
         per-page
         secret-scanning-pagination-before-org-repo
         secret-scanning-pagination-after-org-repo
        """
        url = self._base_url + f"/repos/{owner}/{repo}/secret-scanning/alerts"
        response = self._execute("get", url, payload)
        return response

    def get_a_secret_scanning_alert(self, owner, repo, alert_number, payload=None):
        """
        Get a secret scanning alert
        https://docs.github.com/rest/reference/secret-scanning#get-a-secret-scanning-alert
        Attributes:
        Path Parameters:
        owner
        repo
        alert_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/secret-scanning/alerts/{alert_number}"
        response = self._execute("get", url, payload)
        return response

    def update_a_secret_scanning_alert(self, owner, repo, alert_number, payload=None):
        """
        Update a secret scanning alert
        https://docs.github.com/rest/reference/secret-scanning#update-a-secret-scanning-alert
        Attributes:
        Path Parameters:
        owner
        repo
        alert_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/secret-scanning/alerts/{alert_number}"
        response = self._execute("patch", url, payload)
        return response

    def list_locations_for_a_secret_scanning_alert(self, owner, repo, alert_number, payload=None):
        """
        List locations for a secret scanning alert
        https://docs.github.com/rest/reference/secret-scanning#list-locations-for-a-secret-scanning-alert
        Attributes:
        Path Parameters:
        owner
        repo
        alert_number
        Payload Parameters:
        page
         per-page
        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/secret-scanning/alerts/{alert_number}/locations"
        )
        response = self._execute("get", url, payload)
        return response



"""
Insight into codes of conduct for your communities.
"""


class CodesOfConduct:
    """
    Insight into codes of conduct for your communities.
    """

    def __init__(self, client):
        """
        Initialize the CodesOfConduct class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_all_codes_of_conduct(self, payload=None):
        """
        Get all codes of conduct
        https://docs.github.com/rest/reference/codes-of-conduct#get-all-codes-of-conduct
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/codes_of_conduct"
        response = self._execute("get", url, payload)
        return response

    def get_a_code_of_conduct(self, key, payload=None):
        """
        Get a code of conduct
        https://docs.github.com/rest/reference/codes-of-conduct#get-a-code-of-conduct
        Attributes:
        Path Parameters:
        key
        Payload Parameters:

        """
        url = self._base_url + f"/codes_of_conduct/{key}"
        response = self._execute("get", url, payload)
        return response



"""
Provisioning of GitHub organization membership for SCIM-enabled providers.
"""


class Scim:
    """
    Provisioning of GitHub organization membership for SCIM-enabled providers.
    """

    def __init__(self, client):
        """
        Initialize the Scim class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_scim_provisioned_identities(self, org, payload=None):
        """
        List SCIM provisioned identities
        https://docs.github.com/rest/reference/scim#list-scim-provisioned-identities
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        startIndex
         count
         filter
        """
        url = self._base_url + f"/scim/v2/organizations/{org}/Users"
        response = self._execute("get", url, payload)
        return response

    def provision_and_invite_a_scim_user(self, org, payload=None):
        """
        Provision and invite a SCIM user
        https://docs.github.com/rest/reference/scim#provision-and-invite-a-scim-user
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/organizations/{org}/Users"
        response = self._execute("post", url, payload)
        return response

    def get_scim_provisioning_information_for_a_user(self, org, scim_user_id, payload=None):
        """
        Get SCIM provisioning information for a user
        https://docs.github.com/rest/reference/scim#get-scim-provisioning-information-for-a-user
        Attributes:
        Path Parameters:
        org
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/organizations/{org}/Users/{scim_user_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_provisioned_organization_membership(self, org, scim_user_id, payload=None):
        """
        Update a provisioned organization membership
        https://docs.github.com/rest/reference/scim#set-scim-information-for-a-provisioned-user
        Attributes:
        Path Parameters:
        org
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/organizations/{org}/Users/{scim_user_id}"
        response = self._execute("put", url, payload)
        return response

    def update_an_attribute_for_a_scim_user(self, org, scim_user_id, payload=None):
        """
        Update an attribute for a SCIM user
        https://docs.github.com/rest/reference/scim#update-an-attribute-for-a-scim-user
        Attributes:
        Path Parameters:
        org
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/organizations/{org}/Users/{scim_user_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_scim_user_from_an_organization(self, org, scim_user_id, payload=None):
        """
        Delete a SCIM user from an organization
        https://docs.github.com/rest/reference/scim#delete-a-scim-user-from-an-organization
        Attributes:
        Path Parameters:
        org
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/organizations/{org}/Users/{scim_user_id}"
        response = self._execute("delete", url, payload)
        return response



"""
Endpoints to access Dependency Graph features.
"""


class DependencyGraph:
    """
    Endpoints to access Dependency Graph features.
    """

    def __init__(self, client):
        """
        Initialize the DependencyGraph class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_a_diff_of_the_dependencies_between_commits(self, owner, repo, basehead, payload=None):
        """
        Get a diff of the dependencies between commits
        https://docs.github.com/rest/reference/dependency-graph#get-a-diff-of-the-dependencies-between-commits
        Attributes:
        Path Parameters:
        owner
        repo
        basehead
        Payload Parameters:
        manifest-path
        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependency-graph/compare/{basehead}"
        response = self._execute("get", url, payload)
        return response

    def get_snapshot_dependencies_for_a_repository(self, owner, repo, payload=None):
        """
        Get snapshot dependencies for a repository
        https://docs.github.com/rest/reference/repos#dependency-graph/get-snapshot-dependencies-for-repo
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependency-graph/dependencies"
        response = self._execute("get", url, payload)
        return response

    def create_a_snapshot_of_dependencies_for_a_repository(self, owner, repo, payload=None):
        """
        Create a snapshot of dependencies for a repository
        https://docs.github.com/rest/reference/dependency-graph#create-a-snapshot-of-dependencies-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependency-graph/snapshots"
        response = self._execute("post", url, payload)
        return response



"""
Owner or admin management of users interactions.
"""


class Interactions:
    """
    Owner or admin management of users interactions.
    """

    def __init__(self, client):
        """
        Initialize the Interactions class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_interaction_restrictions_for_an_organization(self, org, payload=None):
        """
        Get interaction restrictions for an organization
        https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/interaction-limits"
        response = self._execute("get", url, payload)
        return response

    def set_interaction_restrictions_for_an_organization(self, org, payload=None):
        """
        Set interaction restrictions for an organization
        https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/interaction-limits"
        response = self._execute("put", url, payload)
        return response

    def remove_interaction_restrictions_for_an_organization(self, org, payload=None):
        """
        Remove interaction restrictions for an organization
        https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/interaction-limits"
        response = self._execute("delete", url, payload)
        return response

    def get_interaction_restrictions_for_a_repository(self, owner, repo, payload=None):
        """
        Get interaction restrictions for a repository
        https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/interaction-limits"
        response = self._execute("get", url, payload)
        return response

    def set_interaction_restrictions_for_a_repository(self, owner, repo, payload=None):
        """
        Set interaction restrictions for a repository
        https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/interaction-limits"
        response = self._execute("put", url, payload)
        return response

    def remove_interaction_restrictions_for_a_repository(self, owner, repo, payload=None):
        """
        Remove interaction restrictions for a repository
        https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/interaction-limits"
        response = self._execute("delete", url, payload)
        return response

    def get_interaction_restrictions_for_your_public_repositories(self, payload=None):
        """
        Get interaction restrictions for your public repositories
        https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-your-public-repositories
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/interaction-limits"
        response = self._execute("get", url, payload)
        return response

    def set_interaction_restrictions_for_your_public_repositories(self, payload=None):
        """
        Set interaction restrictions for your public repositories
        https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-your-public-repositories
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/interaction-limits"
        response = self._execute("put", url, payload)
        return response

    def remove_interaction_restrictions_from_your_public_repositories(self, payload=None):
        """
        Remove interaction restrictions from your public repositories
        https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-from-your-public-repositories
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/interaction-limits"
        response = self._execute("delete", url, payload)
        return response
